import React from 'react'
import { mount } from 'enzyme'
import configureStore from 'redux-mock-store'
import { Provider } from 'react-redux'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import { profileData } from '../../../tests/__mocks__/profile.mock'
import ActionDone from './ActionDone'
import { Button } from '@material-ui/core'
import * as reactRedux from 'react-redux'
import * as challengeActions from 'store/challenge/challenge.actions'
import { act } from 'react-dom/test-utils'
import UsageEventService from 'services/usageEvent.service'

const mockStore = configureStore([])
jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
jest.mock('services/usageEvent.service')
const mockAddEvent = jest.fn()
UsageEventService.addEvent = mockAddEvent

const mockHistoryGoBack = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useHistory: () => ({
    goBack: mockHistoryGoBack,
  }),
}))
const mockupdateUserChallenge = jest.fn()
jest.mock('services/challenge.service', () => {
  return jest.fn(() => {
    return {
      updateUserChallenge: mockupdateUserChallenge,
    }
  })
})

describe('ActionDone component', () => {
  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ActionDone currentChallenge={userChallengeData[1]} />
      </Provider>
    )
    expect(wrapper).toMatchSnapshot()
  })
  it('should click on button and update action to done', async () => {
    const useDispatchSpy = jest.spyOn(reactRedux, 'useDispatch')
    const updateChallengeSpy = jest.spyOn(
      challengeActions,
      'updateUserChallengeList'
    )
    const store = mockStore({
      ecolyo: {
        challenge: userChallengeData[1],
        global: { ...globalStateData, fluidTypes: [0, 1, 2] },
        profile: profileData,
      },
    })
    mockupdateUserChallenge.mockResolvedValueOnce(userChallengeData[1])
    useDispatchSpy.mockReturnValue(jest.fn())
    const wrapper = mount(
      <Provider store={store}>
        <ActionDone currentChallenge={userChallengeData[1]} />
      </Provider>
    )
    wrapper.find(Button).first().simulate('click')
    await act(async () => {
      await new Promise(resolve => setTimeout(resolve))
      wrapper.update()
    })
    expect(updateChallengeSpy).toBeCalledTimes(1)
  })
})
