import React, { useCallback } from 'react'
import { UserChallenge } from 'models'
import { Button } from '@material-ui/core'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { UserChallengeUpdateFlag } from 'enum/userChallenge.enum'
import ChallengeService from 'services/challenge.service'
import { updateUserChallengeList } from 'store/challenge/challenge.actions'
import { useDispatch } from 'react-redux'
import { useClient } from 'cozy-client'
import { useHistory } from 'react-router-dom'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import starFilled from 'assets/icons/visu/challenge/starFilled.svg'
import './actionDone.scss'
import { toggleChallengeActionNotification } from 'store/global/global.actions'
import { UsageEventType } from 'enum/usageEvent.enum'
import UsageEventService from 'services/usageEvent.service'
interface ActionDoneProps {
  currentChallenge: UserChallenge
}

const ActionDone: React.FC<ActionDoneProps> = ({
  currentChallenge,
}: ActionDoneProps) => {
  const { t } = useI18n()
  const client = useClient()
  const dispatch = useDispatch()
  const history = useHistory()
  const handleEndAction = useCallback(async () => {
    const challengeService = new ChallengeService(client)
    const updatedChallenge: UserChallenge =
      await challengeService.updateUserChallenge(
        currentChallenge,
        UserChallengeUpdateFlag.ACTION_DONE
      )
    await UsageEventService.addEvent(client, {
      type: UsageEventType.ACTION_END_EVENT,
      target: currentChallenge.action.ecogesture
        ? currentChallenge.action.ecogesture.id
        : '',
      context: currentChallenge.id,
      startDate: currentChallenge.action.startDate,
    })
    dispatch(toggleChallengeActionNotification(false))
    dispatch(updateUserChallengeList(updatedChallenge))
    history.goBack()
  }, [currentChallenge, dispatch, client, history])

  return (
    <div className="action-done-container">
      <div className="action-done">
        <div className="result-title"> {t('action.finished')}</div>
        <div className="result-text text-16-normal">
          {t('action.resultText1')}
        </div>
        <div className="result-text text-16-normal">
          {t('action.resultText2')}
        </div>
        <div className="result-text text-16-normal">
          {t('action.resultText3')}
        </div>
        <div className="result-text text-16-normal">
          {t('action.resultText4')}
        </div>
        <div className="stars">
          <span>5</span>
          <StyledIcon icon={starFilled} size={33} />
        </div>
        <Button
          classes={{
            root: 'btn-secondary-negative btn-detail',
            label: 'text-16-normal',
          }}
          onClick={handleEndAction}
        >
          {t('action.ok')}
        </Button>
      </div>
    </div>
  )
}

export default ActionDone
