import React from 'react'
import { mount } from 'enzyme'
import AnalysisErrorModal from 'components/Analysis/AnalysisErrorModal'
import configureStore from 'redux-mock-store'
import { profileData } from '../../../tests/__mocks__/profile.mock'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { Provider } from 'react-redux'
import Dialog from '@material-ui/core/Dialog'
import Button from '@material-ui/core/Button'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockHistoryPush = jest.fn()
const mockHistoryGoBack = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useHistory: () => ({
    push: mockHistoryPush,
    goBack: mockHistoryGoBack,
  }),
}))
const mockStore = configureStore([])

describe('AnalysisErrorModal component', () => {
  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        profile: profileData,
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <AnalysisErrorModal />
      </Provider>
    )
    expect(wrapper.find(Dialog).exists()).toBeTruthy()
    expect(wrapper.find(Button).exists()).toBeTruthy()
  })
  it('should redirect to previous page', () => {
    const store = mockStore({
      ecolyo: {
        profile: profileData,
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <AnalysisErrorModal />
      </Provider>
    )
    wrapper.find('.btn-secondary-positive').first().simulate('click')
  })
  it('should redirect to options', () => {
    const store = mockStore({
      ecolyo: {
        profile: profileData,
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <AnalysisErrorModal />
      </Provider>
    )
    wrapper.find('.btn-highlight').first().simulate('click')
  })
})
