import React from 'react'
import { mount } from 'enzyme'
import * as reactRedux from 'react-redux'
import { Provider } from 'react-redux'
import AnalysisView from 'components/Analysis/AnalysisView'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { profileData } from '../../../tests/__mocks__/profile.mock'
import {
  createMockStore,
  mockInitialEcolyoState,
} from '../../../tests/__mocks__/store'
import * as globalActions from 'store/global/global.actions'
import * as profileActions from 'store/profile/profile.actions'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock('components/Content/Content', () => 'mock-content')
jest.mock('components/DateNavigator/DateNavigator', () => 'mock-datenavigator')
jest.mock('components/Analysis/MonthlyAnalysis', () => 'mock-monthlyanalysis')

jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useLocation: () => ({
    pathname: 'ecolyo.cozy.localhost:8080/#/analysis',
  }),
}))

const useSelectorSpy = jest.spyOn(reactRedux, 'useSelector')
const useDispatchSpy = jest.spyOn(reactRedux, 'useDispatch')
const toggleAnalysisNotificationSpy = jest.spyOn(
  globalActions,
  'toggleAnalysisNotification'
)
const updateProfileSpy = jest.spyOn(profileActions, 'updateProfile')

describe('AnalysisView component', () => {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  let store: any
  beforeEach(() => {
    store = createMockStore(mockInitialEcolyoState)
    useSelectorSpy.mockClear()
    useDispatchSpy.mockClear()
    toggleAnalysisNotificationSpy.mockClear()
    updateProfileSpy.mockClear()
  })

  it('should be rendered correctly', () => {
    useSelectorSpy.mockReturnValue({
      global: globalStateData,
      profile: profileData,
    })
    useDispatchSpy.mockReturnValue(jest.fn())
    const wrapper = mount(
      <Provider store={store}>
        <AnalysisView />
      </Provider>
    )
    expect(wrapper.find('mock-cozybar').exists()).toBeTruthy()
    expect(wrapper.find('mock-header').exists()).toBeTruthy()
    expect(wrapper.find('mock-datenavigator').exists()).toBeTruthy()
    expect(wrapper.find('mock-monthlyanalysis').exists()).toBeTruthy()
  })

  it('should update profile and toggle analysis notification to false if notification is true', () => {
    useSelectorSpy.mockReturnValue({
      global: {
        ...globalStateData,
        analysisNotification: true,
      },
      profile: {
        ...profileData,
        haveSeenLastAnalysis: false,
      },
    })
    useDispatchSpy.mockReturnValue(jest.fn())
    const wrapper = mount(
      <Provider store={store}>
        <AnalysisView />
      </Provider>
    )
    expect(wrapper.find('mock-cozybar').exists()).toBeTruthy()
    expect(wrapper.find('mock-header').exists()).toBeTruthy()
    expect(wrapper.find('mock-datenavigator').exists()).toBeTruthy()
    expect(wrapper.find('mock-monthlyanalysis').exists()).toBeTruthy()
    expect(updateProfileSpy).toBeCalledTimes(1)
    expect(updateProfileSpy).toHaveBeenCalledWith({
      haveSeenLastAnalysis: true,
    })
    expect(toggleAnalysisNotificationSpy).toBeCalledTimes(1)
    expect(toggleAnalysisNotificationSpy).toHaveBeenCalledWith(false)
  })
})
