import React, { useState, useEffect, useCallback } from 'react'
import { useSelector, useDispatch } from 'react-redux'
import { updateProfile } from 'store/profile/profile.actions'
import { toggleAnalysisNotification } from 'store/global/global.actions'
import { AppStore } from 'store'

import CozyBar from 'components/Header/CozyBar'
import Header from 'components/Header/Header'
import Content from 'components/Content/Content'
import MonthlyAnalysis from 'components/Analysis/MonthlyAnalysis'
import './analysisView.scss'
import DateNavigator from 'components/DateNavigator/DateNavigator'
import { DateTime } from 'luxon'
import { useLocation } from 'react-router-dom'
import UsageEventService from 'services/usageEvent.service'
import { useClient } from 'cozy-client'
import { UsageEventType } from 'enum/usageEvent.enum'

const AnalysisView: React.FC = () => {
  const client = useClient()
  const [headerHeight, setHeaderHeight] = useState<number>(0)
  const {
    global: { analysisNotification },
    profile: { monthlyAnalysisDate },
  } = useSelector((state: AppStore) => state.ecolyo)

  const { selectedDate } = useSelector((state: AppStore) => state.ecolyo.chart)
  const [currentAnalysisDate, setCurrentAnalysisDate] =
    useState<DateTime>(monthlyAnalysisDate)
  const { mailToken } = useSelector((state: AppStore) => state.ecolyo.profile)
  const dispatch = useDispatch()

  const defineHeaderHeight = useCallback((height: number) => {
    setHeaderHeight(height)
  }, [])

  // Handle email report comeback
  const { search } = useLocation()
  const query = new URLSearchParams(search)
  const paramToken = query.get('token')

  // Scroll handling
  const app = document.querySelector('.app-content')
  const [scrollPosition, setScrollPosition] = useState(0)

  const saveLastScrollPosition = useCallback(() => {
    if (app) {
      const position =
        app.scrollTop > window.pageYOffset ? app.scrollTop : window.pageYOffset
      setScrollPosition(position)
    }
  }, [app])

  useEffect(() => {
    const updateAnalysisNotification = () => {
      if (analysisNotification) {
        dispatch(
          updateProfile({
            haveSeenLastAnalysis: true,
          })
        )
        dispatch(toggleAnalysisNotification(false))
      }

      // Save usageevent came back from email
      if (paramToken && mailToken && paramToken === mailToken) {
        UsageEventService.addEventIfDoesntExist(
          client,
          {
            type: UsageEventType.REPORT_FROM_EMAIL,
            target: 'analysis',
            result: '1',
          },
          {
            type: UsageEventType.REPORT_FROM_EMAIL,
            eventDate: {
              $lt: DateTime.local()
                .setZone('utc', {
                  keepLocalTime: true,
                })
                .endOf('month')
                .toString(),
              $gt: DateTime.local()
                .setZone('utc', {
                  keepLocalTime: true,
                })
                .startOf('month')
                .toString(),
            },
          }
        )
      }
    }

    updateAnalysisNotification()
  }, [
    dispatch,
    analysisNotification,
    monthlyAnalysisDate,
    selectedDate,
    paramToken,
    mailToken,
    client,
  ])

  return (
    <>
      <CozyBar titleKey={'analysis.viewTitle'} />
      <Header
        setHeaderHeight={defineHeaderHeight}
        desktopTitleKey={'analysis.viewTitle'}
      >
        <DateNavigator
          currentAnalysisDate={currentAnalysisDate}
          setCurrentAnalysisDate={setCurrentAnalysisDate}
          inlineDateDisplay={true}
        />
      </Header>
      <Content height={headerHeight}>
        <MonthlyAnalysis
          analysisDate={currentAnalysisDate}
          saveLastScrollPosition={saveLastScrollPosition}
          scrollPosition={scrollPosition}
        />
      </Content>
    </>
  )
}

export default AnalysisView
