import { FluidType } from 'enum/fluid.enum'
import { mount } from 'enzyme'
import React from 'react'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import ChallengeCardUnlocked from './ChallengeCardUnlocked'
import ChallengeNoFluidModal from './ChallengeNoFluidModal'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockStartUserChallenge = jest.fn()
jest.mock('services/challenge.service', () => {
  return jest.fn(() => {
    return {
      startUserChallenge: mockStartUserChallenge,
    }
  })
})
const mockImportIconbyId = jest.fn()
jest.mock('utils/utils', () => {
  return {
    importIconbyId: jest.fn(() => mockImportIconbyId),
    getChallengeTitleWithLineReturn: jest.fn(() => 'Challenge 1'),
  }
})

const mockStore = configureStore([])

describe('ChallengeCardUnlocked component', () => {
  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ChallengeCardUnlocked userChallenge={userChallengeData[0]} />
      </Provider>
    )
    expect(wrapper.find('.challengeTitle').text()).toEqual(
      userChallengeData[0].title
    )
    expect(wrapper.find('.btn-duel-active').exists()).toBeTruthy()
    expect(wrapper.find(ChallengeNoFluidModal).exists()).toBeTruthy()
    expect(wrapper.find(ChallengeNoFluidModal).prop('open')).toBeFalsy()
  })

  it('should display ChallengeNoFluidModal when launching challenge without configured fluid', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ChallengeCardUnlocked userChallenge={userChallengeData[0]} />
      </Provider>
    )
    wrapper.find('.btn-duel-active').first().simulate('click')
    expect(wrapper.find(ChallengeNoFluidModal).exists()).toBeTruthy()
    expect(wrapper.find(ChallengeNoFluidModal).prop('open')).toBeTruthy()
  })

  it('should not display ChallengeNoFluidModal and update userChallenge when launching challenge with configured fluid', () => {
    const updateGlobalStoreData = {
      ...globalStateData,
      fluidTypes: [FluidType.ELECTRICITY],
      fluidStatus: [{ status: 200 }],
    }
    const store = mockStore({
      ecolyo: {
        global: updateGlobalStoreData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <ChallengeCardUnlocked userChallenge={userChallengeData[0]} />
      </Provider>
    )
    wrapper.find('.btn-duel-active').first().simulate('click')
    expect(wrapper.find(ChallengeNoFluidModal).exists()).toBeTruthy()
    expect(wrapper.find(ChallengeNoFluidModal).prop('open')).toBeFalsy()
    expect(mockStartUserChallenge).toHaveBeenCalledWith(userChallengeData[0])
  })
})
