import React, { useState } from 'react'
import { ScaleBand, ScaleLinear } from 'd3-scale'
import { DateTime } from 'luxon'
import { detect } from 'detect-browser'
import { Dataload } from 'models'

interface BarProps {
  index: number
  dataload: Dataload
  xScale: ScaleBand<string>
  yScale: ScaleLinear<number, number>
  height: number
  average: number
}

const UncomingBar = ({
  index,
  dataload,
  xScale,
  yScale,
  height,
  average,
}: BarProps) => {
  dataload.value = average
  const [animationEnded, setAnimationEnded] = useState(false)
  const browser = detect()
  const onAnimationEnd = () => {
    setAnimationEnded(true)
  }

  const barClass = animationEnded
    ? `bar-UNCOMING `
    : `bar-UNCOMING bounce-${browser?.name !== 'edge' ? '1' : '3'} delay--${
        index % 13
      }`

  const getBandWidth = (): number => {
    return xScale.bandwidth()
  }

  const topRoundedRectDashedLine = (
    _x: number,
    _y: number,
    _width: number,
    _height: number
  ): string => {
    const radius = _height > 4 ? 4 : _height / 4
    return (
      'M' +
      _x +
      ',' +
      (_y + radius + (_height - radius)) +
      'v-' +
      (_height - radius) +
      ' a' +
      radius +
      ',' +
      radius +
      ' 0 0 1 ' +
      radius +
      ',' +
      -radius +
      'h' +
      (_width - 2 * radius) +
      'a' +
      radius +
      ',' +
      radius +
      ' 0 0 1 ' +
      radius +
      ',' +
      radius +
      'v' +
      (_height - radius)
    )
  }

  return (
    <g>
      {height > 0 ? (
        <g
          transform={`translate(${xScale(
            dataload.date.toLocaleString(DateTime.DATETIME_SHORT)
          )}, -40)`}
        >
          <rect
            x="0"
            y="0"
            width={getBandWidth()}
            height={height + 40}
            className={`background-false`}
            fill="#E0E0E0"
          />
        </g>
      ) : null}
      {height > 0 && dataload.value && dataload.value >= 0 ? (
        <g
          transform={`translate(${xScale(
            dataload.date.toLocaleString(DateTime.DATETIME_SHORT)
          )}, ${yScale(dataload.value)})`}
        >
          <path
            d={topRoundedRectDashedLine(
              0,
              0,
              getBandWidth(),
              height - yScale(dataload.value)
            )}
            fill="url(#gradient)"
            strokeDasharray="5"
            stroke={'#61f0f2'}
            onAnimationEnd={onAnimationEnd}
            className={barClass}
          />
        </g>
      ) : null}
    </g>
  )
}

export default UncomingBar
