import React from 'react'
import { FluidType } from 'enum/fluid.enum'
import Switch, { SwitchProps } from '@material-ui/core/Switch'
import { withStyles } from '@material-ui/core/styles'

const SwitchBase = withStyles({
  root: {
    paddingLeft: 0,
    width: 52,
    overflow: 'initial',
  },
  switchBase: {
    color: 'var(--greyBright)',
    width: 'auto',
    left: -8,
    '&$checked': {
      color: 'var(--greyBright)',
      '& + $track': {
        opacity: 1,
        backgroundColor: 'var(--multiColor)',
      },
    },
  },
  checked: {},
  track: {
    opacity: 1,
    backgroundColor: 'var(--greyDark)',
    marginTop: 'initial',
    marginLeft: 'initial',
    left: 0,
  },
})(Switch)

const SwitchElec = withStyles({
  switchBase: {
    '&$checked': {
      '& + $track': {
        backgroundColor: 'var(--elecColor)',
      },
    },
  },
  checked: {},
  track: {},
})(SwitchBase)

const SwitchWater = withStyles({
  switchBase: {
    '&$checked': {
      '& + $track': {
        backgroundColor: 'var(--waterColor)',
      },
    },
  },
  checked: {},
  track: {},
})(SwitchBase)

const SwitchGas = withStyles({
  switchBase: {
    '&$checked': {
      '& + $track': {
        backgroundColor: 'var(--gasColor)',
      },
    },
  },
  checked: {},
  track: {},
})(SwitchBase)

interface StyledSwitchProps extends SwitchProps {
  fluidType?: FluidType
}

const StyledSwitch: React.ComponentType<StyledSwitchProps> = ({
  fluidType,
  ...props
}: StyledSwitchProps) => {
  if (fluidType !== undefined) {
    switch (fluidType) {
      case FluidType.ELECTRICITY:
        return <SwitchElec {...props} />
      case FluidType.WATER:
        return <SwitchWater {...props} />
      case FluidType.GAS:
        return <SwitchGas {...props} />
      default:
        return <SwitchBase {...props} />
    }
  } else {
    return <SwitchBase {...props} />
  }
}

export default StyledSwitch
