import React from 'react'
import { mount } from 'enzyme'
import { DateTime } from 'luxon'
import * as reactRedux from 'react-redux'
import { act } from 'react-dom/test-utils'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import DateNavigator from './DateNavigator'
import { mockInitialChartState } from '../../../tests/__mocks__/store'
import { IconButton } from '@material-ui/core'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockStore = configureStore([])

const mockUseDispatch = jest.spyOn(reactRedux, 'useDispatch')

describe('DateNavigator component', () => {
  it('should be rendered correctly', () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        chart: mockInitialChartState,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <DateNavigator
          currentAnalysisDate={DateTime.fromISO('2021-07-01T00:00:00.000Z', {
            zone: 'utc',
          })}
        />
      </Provider>
    ).getElement()
    expect(wrapper).toMatchSnapshot()
  })
  it('should click on left arrow and change date', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        chart: mockInitialChartState,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <DateNavigator
          currentAnalysisDate={DateTime.fromISO('2021-07-01T00:00:00.000Z', {
            zone: 'utc',
          })}
        />
      </Provider>
    )
    await act(async () => {
      await new Promise(resolve => setTimeout(resolve))
      wrapper.update()
    })
    wrapper.find(IconButton).first().simulate('click')
    expect(mockUseDispatch).toHaveBeenCalledTimes(2)
  })
  it('should click on right arrow and change date', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        chart: mockInitialChartState,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <DateNavigator currentAnalysisDate={DateTime.now()} />
      </Provider>
    )
    await act(async () => {
      await new Promise(resolve => setTimeout(resolve))
      wrapper.update()
    })
    wrapper.find(IconButton).at(1).simulate('click')
    expect(mockUseDispatch).toHaveBeenCalledTimes(3)
  })

  it('should be rendered without analysis date and change to previous index', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        chart: mockInitialChartState,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <DateNavigator />
      </Provider>
    )
    await act(async () => {
      await new Promise(resolve => setTimeout(resolve))
      wrapper.update()
    })
    wrapper.find(IconButton).at(0).simulate('click')
    expect(mockUseDispatch).toHaveBeenCalledTimes(4)
  })
  it('should be rendered without analysis date and change to next index', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        chart: mockInitialChartState,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <DateNavigator />
      </Provider>
    )
    await act(async () => {
      await new Promise(resolve => setTimeout(resolve))
      wrapper.update()
    })
    wrapper.find(IconButton).at(1).simulate('click')
    expect(mockUseDispatch).toHaveBeenCalledTimes(5)
  })
})
