import React, { useEffect, useState } from 'react'
import './duelEmptyValueModal.scss'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'

import Icon from 'cozy-ui/transpiled/react/Icon'
import Dialog from '@material-ui/core/Dialog'
import Button from '@material-ui/core/Button'

import defaultIcon from 'assets/icons/visu/duelResult/default.svg'
import { importIconbyId } from 'utils/utils'

interface DuelEmptyValueModalProps {
  open: boolean
  handleCloseClick: () => void
}

const DuelEmptyValueModal: React.FC<DuelEmptyValueModalProps> = ({
  open,
  handleCloseClick,
}: DuelEmptyValueModalProps) => {
  const { t } = useI18n()
  const [emptyIcon, setEmptyIcon] = useState<string>(defaultIcon)
  useEffect(() => {
    async function handleEcogestureIcon() {
      const icon = await importIconbyId('emptyValue', 'duel')
      if (icon) {
        setEmptyIcon(icon)
      } else {
        setEmptyIcon(defaultIcon)
      }
    }

    handleEcogestureIcon()
  }, [])

  return (
    <Dialog
      open={open}
      onClose={handleCloseClick}
      aria-labelledby={'accessibility-title'}
      classes={{
        root: 'modal-root',
        paper: 'modal-paper blue-border',
      }}
    >
      <div id={'accessibility-title'}>
        {t('duel_empty_value_modal.accessibility.window_title')}
      </div>
      <div className="modal-empty-value-root">
        <Icon className="imgResult" icon={emptyIcon} size={208} />
        <div className="text-28-normal-uppercase modal-empty-value-title">
          {t('duel_empty_value_modal.title')}
        </div>
        <div className="text-18-normal">
          {t('duel_empty_value_modal.message')}
        </div>
        <Button
          aria-label={t('duel_empty_value_modal.accessibility.button_validate')}
          onClick={handleCloseClick}
          classes={{
            root: 'btn-secondary-negative',
            label: 'text-16-normal',
          }}
        >
          {t('duel_empty_value_modal.button')}
        </Button>
      </div>
    </Dialog>
  )
}

export default DuelEmptyValueModal
