import React from 'react'
import { shallow } from 'enzyme'
import * as reactRedux from 'react-redux'
import DuelView from 'components/Duel/DuelView'
import { UserChallengeState } from 'enum/userChallenge.enum'
import { challengeStateData } from '../../../tests/__mocks__/challengeStateData.mock'
import { userChallengeData } from '../../../tests/__mocks__/userChallengeData.mock'
import DuelError from './DuelError'
import DuelUnlocked from './DuelUnlocked'
import DuelOngoing from './DuelOngoing'
import { UserDuelState } from 'enum/userDuel.enum'

jest.mock('components/Header/CozyBar', () => 'mock-cozybar')
jest.mock('components/Header/Header', () => 'mock-header')
jest.mock('components/Content/Content', () => 'mock-content')

const mockUseSelector = jest.spyOn(reactRedux, 'useSelector')

const mockHistoryGoBack = jest.fn()
jest.mock('react-router-dom', () => ({
  useLocation: () => ({
    search: '?id=CHALLENGE0002',
  }),
  useHistory: () => ({
    goBack: mockHistoryGoBack,
  }),
}))

describe('DuelView component', () => {
  it('should be rendered with DuelError component when no current challenge', () => {
    mockUseSelector.mockReturnValue(challengeStateData)
    const wrapper = shallow(<DuelView />)
    expect(wrapper.find(DuelError).exists()).toBeTruthy()
  })

  it('should be rendered with DuelOngoing component when current challenge with state = duel and duel state = done', () => {
    const updatedUserChallenge = {
      ...userChallengeData[1],
      state: UserChallengeState.DUEL,
      duel: { ...userChallengeData[1].duel, state: UserDuelState.DONE },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      userChallengeList: userChallengeData,
      currentChallenge: updatedUserChallenge,
    }
    updatedChallengeState.userChallengeList[1] = updatedUserChallenge
    mockUseSelector.mockReturnValue(updatedChallengeState)
    const wrapper = shallow(<DuelView />)
    expect(wrapper.find(DuelOngoing).exists()).toBeTruthy()
  })

  it('should be rendered with DuelError component when current challenge with state = duel and duel state = locked', () => {
    const updatedUserChallenge = {
      ...userChallengeData[1],
      state: UserChallengeState.DUEL,
      duel: { ...userChallengeData[1].duel, state: UserDuelState.LOCKED },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      userChallengeList: userChallengeData,
      currentChallenge: updatedUserChallenge,
    }
    updatedChallengeState.userChallengeList[1] = updatedUserChallenge
    mockUseSelector.mockReturnValue(updatedChallengeState)
    const wrapper = shallow(<DuelView />)
    expect(wrapper.find(DuelError).exists()).toBeTruthy()
  })

  it('should be rendered with DuelError component when current challenge with state != duel ', () => {
    const updatedUserChallenge = {
      ...userChallengeData[1],
      state: UserChallengeState.ONGOING,
    }
    const updatedChallengeState = {
      ...challengeStateData,
      userChallengeList: userChallengeData,
      currentChallenge: updatedUserChallenge,
    }
    updatedChallengeState.userChallengeList[1] = updatedUserChallenge
    mockUseSelector.mockReturnValue(updatedChallengeState)
    const wrapper = shallow(<DuelView />)
    expect(wrapper.find(DuelError).exists()).toBeTruthy()
  })

  it('should be rendered with DuelUnlocked component when current challenge with state = duel  and duel state = unlocked', () => {
    const updatedUserChallenge = {
      ...userChallengeData[1],
      state: UserChallengeState.DUEL,
      duel: { ...userChallengeData[1].duel, state: UserDuelState.UNLOCKED },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      userChallengeList: userChallengeData,
      currentChallenge: updatedUserChallenge,
    }
    updatedChallengeState.userChallengeList[1] = updatedUserChallenge
    mockUseSelector.mockReturnValue(updatedChallengeState)
    const wrapper = shallow(<DuelView />)
    expect(wrapper.find(DuelUnlocked).exists()).toBeTruthy()
  })

  it('should be rendered with DuelOngoing component when current challenge with state = duel  and duel state = ongoing', () => {
    const updatedUserChallenge = {
      ...userChallengeData[1],
      state: UserChallengeState.DUEL,
      duel: { ...userChallengeData[1].duel, state: UserDuelState.ONGOING },
    }
    const updatedChallengeState = {
      ...challengeStateData,
      userChallengeList: userChallengeData,
      currentChallenge: updatedUserChallenge,
    }
    updatedChallengeState.userChallengeList[1] = updatedUserChallenge
    mockUseSelector.mockReturnValue(updatedChallengeState)
    const wrapper = shallow(<DuelView />)
    expect(wrapper.find(DuelOngoing).exists()).toBeTruthy()
  })
})
