import React from 'react'
import { mount } from 'enzyme'
import * as reactRedux from 'react-redux'
import toJson from 'enzyme-to-json'
import { Provider } from 'react-redux'
import configureStore from 'redux-mock-store'
import { challengeStateData } from '../../../tests/__mocks__/challengeStateData.mock'
import { globalStateData } from '../../../tests/__mocks__/globalStateData.mock'
import { waitForComponentToPaint } from '../../../tests/__mocks__/testUtils'
import EcogestureFormEquipment from './EcogestureFormEquipment'
import { mockProfileEcogesture } from '../../../tests/__mocks__/profileEcogesture.mock'
import { Button } from '@material-ui/core'
import { mockInitialEcolyoState } from '../../../tests/__mocks__/store'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockStore = configureStore([])
const mockSetPreviousStep = jest.fn()
const useSelectorSpy = jest.spyOn(reactRedux, 'useSelector')

const mockHistoryPush = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useHistory: () => ({
    push: mockHistoryPush,
  }),
}))
jest.mock('./EquipmentIcon', () => 'mock-equipment-icon')
const mockUseDispatch = jest.spyOn(reactRedux, 'useDispatch')

describe('EcogestureFormEquipment component', () => {
  useSelectorSpy.mockReturnValue({
    ...mockInitialEcolyoState.profile,
  })

  it('should be rendered correctly', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormEquipment
          profileEcogesture={mockProfileEcogesture}
          setPreviousStep={mockSetPreviousStep}
          setNextStep={jest.fn()}
          step={0}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    expect(toJson(wrapper)).toMatchSnapshot()
  })
  it('should finish the form', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })
    mockUseDispatch.mockReturnValue(jest.fn())

    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormEquipment
          profileEcogesture={mockProfileEcogesture}
          setPreviousStep={mockSetPreviousStep}
          setNextStep={jest.fn()}
          step={0}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find(Button).at(1).simulate('click')
    expect(mockUseDispatch).toHaveBeenCalledTimes(2)
  })
  it('should select equipment and unselect it', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })

    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormEquipment
          profileEcogesture={mockProfileEcogesture}
          setPreviousStep={mockSetPreviousStep}
          setNextStep={jest.fn()}
          step={0}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find('.item-eq').first().simulate('change')
    await waitForComponentToPaint(wrapper)

    expect(wrapper.find('.item-eq').first().hasClass('checked')).toBeTruthy
    wrapper.find('.checked').first().simulate('change')
    await waitForComponentToPaint(wrapper)
    expect(wrapper.find('.item-eq').first().hasClass('checked')).toBeFalsy()
  })

  it('should click on disabled back button', async () => {
    const store = mockStore({
      ecolyo: {
        global: globalStateData,
        challenge: challengeStateData,
      },
    })
    const wrapper = mount(
      <Provider store={store}>
        <EcogestureFormEquipment
          profileEcogesture={mockProfileEcogesture}
          setPreviousStep={mockSetPreviousStep}
          setNextStep={jest.fn()}
          step={0}
        />
      </Provider>
    )
    await waitForComponentToPaint(wrapper)
    wrapper.find(Button).first().simulate('click')
    await waitForComponentToPaint(wrapper)

    expect(wrapper.find('.icons-container').exists()).toBeTruthy()
  })
})
