import React, { useEffect, useState } from 'react'
import './ecogestureSelectionDetail.scss'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import { Button } from '@material-ui/core'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { Ecogesture } from 'models'
import objectiveIcon from 'assets/icons/ico/objective-enabled.svg'
import doingIcon from 'assets/icons/ico/doing-enabled.svg'
import skipIcon from 'assets/icons/ico/skip-enabled.svg'
import defaultIcon from 'assets/icons/visu/ecogesture/default.svg'
import { importIconbyId } from 'utils/utils'

interface EcogestureSelectionDetailProps {
  ecogesture: Ecogesture
  validate: (objective: boolean, doing: boolean) => void
  title: string
}

const EcogestureSelectionDetail: React.FC<EcogestureSelectionDetailProps> = ({
  ecogesture,
  validate,
  title,
}: EcogestureSelectionDetailProps) => {
  const { t } = useI18n()
  const [ecogestureIcon, setEcogestureIcon] = useState<string>('')

  useEffect(() => {
    let subscribed = true
    async function getIcon() {
      const _icon = await importIconbyId(ecogesture.id, 'ecogesture')
      if (subscribed) {
        if (_icon) {
          setEcogestureIcon(_icon)
        } else {
          setEcogestureIcon(defaultIcon)
        }
      }
    }
    getIcon()
    return () => {
      subscribed = false
    }
  }, [ecogesture.id])

  return (
    <div className="eg-selection-detail-container">
      <div className="content">
        <StyledIcon className="icon" icon={ecogestureIcon} size={240} />
        <div className="text-22 title">{title}</div>
        <div className="text text-18-bold">{ecogesture.longName}</div>
      </div>
      <div className="buttons">
        <Button
          aria-label={t('ecogesture_selection.button_objective')}
          classes={{
            root: 'btn-secondary-negative',
            label: 'text-14-bold',
            focusVisible: 'noFocus',
          }}
          onClick={() => validate(true, false)}
        >
          <StyledIcon icon={objectiveIcon} size={60} />
          {t('ecogesture_selection.button_objective')}
        </Button>
        <Button
          aria-label={t('ecogesture_selection.button_doing')}
          classes={{
            root: 'btn-secondary-negative',
            label: 'text-14-bold',
            focusVisible: 'noFocus',
          }}
          onClick={() => validate(false, true)}
        >
          <StyledIcon icon={doingIcon} size={60} />
          {t('ecogesture_selection.button_doing')}
        </Button>
        <Button
          aria-label={t('ecogesture_selection.button_skip')}
          classes={{
            root: 'btn-secondary-negative',
            label: 'text-14-bold',
            focusVisible: 'noFocus',
          }}
          onClick={() => validate(false, false)}
        >
          <StyledIcon icon={skipIcon} size={60} />
          {t('ecogesture_selection.button_skip')}
        </Button>
      </div>
    </div>
  )
}

export default EcogestureSelectionDetail
