import React from 'react'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import EcogestureSelectionRestart from './EcogestureSelectionRestart'
import { Button } from '@material-ui/core'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})
const mockHistoryPush = jest.fn()
jest.mock('react-router-dom', () => ({
  ...jest.requireActual('react-router-dom'),
  useHistory: () => ({
    push: mockHistoryPush,
  }),
}))
const mockRestart = jest.fn()

describe('EcogestureSelectionRestart component', () => {
  beforeEach(() => {
    mockHistoryPush.mockClear()
    mockRestart.mockClear()
  })

  it('should be rendered correctly', () => {
    const wrapper = mount(
      <EcogestureSelectionRestart listLength={10} restart={mockRestart} />
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should call go to the ecogesture view when user click on the button', () => {
    const wrapper = mount(
      <EcogestureSelectionRestart listLength={10} restart={mockRestart} />
    )
    wrapper.find(Button).at(0).simulate('click')
    expect(mockHistoryPush).toHaveBeenCalledWith('/ecogestures?tab=0')
  })

  it('should call the restart when user click on the button', () => {
    const wrapper = mount(
      <EcogestureSelectionRestart listLength={10} restart={mockRestart} />
    )
    wrapper.find(Button).at(1).simulate('click')
    expect(mockRestart).toHaveBeenCalledTimes(1)
  })
})
