import React from 'react'
import { Provider } from 'react-redux'
import { mount } from 'enzyme'
import toJson from 'enzyme-to-json'
import {
  createMockStore,
  mockInitialEcolyoState,
} from '../../../tests/__mocks__/store'
import { Button } from '@material-ui/core'
import ExportDoneModal from 'components/Export/exportDoneModal'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockHandleClose = jest.fn()

describe('exportDoneModal component', () => {
  let store: any
  beforeEach(() => {
    store = createMockStore(mockInitialEcolyoState)
  })

  it('should be rendered correctly', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ExportDoneModal
          open={true}
          error={false}
          handleCloseClick={mockHandleClose}
        />
      </Provider>
    )
    expect(toJson(wrapper)).toMatchSnapshot()
  })

  it('should display error message', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ExportDoneModal
          open={true}
          error={true}
          handleCloseClick={mockHandleClose}
        />
      </Provider>
    )
  })

  it('should close modal ', () => {
    const wrapper = mount(
      <Provider store={store}>
        <ExportDoneModal
          open={true}
          error={false}
          handleCloseClick={mockHandleClose}
        />
      </Provider>
    )
    wrapper.find(Button).first().simulate('click')
    expect(mockHandleClose).toHaveBeenCalledTimes(1)
  })
})
