import BackArrowIcon from 'assets/icons/ico/back-arrow.svg'
import FeedbackIcon from 'assets/icons/ico/feedback.svg'
import StyledIconButton from 'components/CommonKit/IconButton/StyledIconButton'
import { useI18n } from 'cozy-ui/transpiled/react/I18n'
import { ScreenType } from 'enum/screen.enum'
import React, { useCallback } from 'react'
import { useDispatch, useSelector } from 'react-redux'
import { useHistory } from 'react-router-dom'
import { AppStore } from 'store'
import { updateModalIsFeedbacksOpen } from 'store/modal/modal.actions'

interface CozyBarProps {
  titleKey?: string
  displayBackArrow?: boolean
  isNotKey?: boolean
  backFunction?: () => void
}

const CozyBar = ({
  titleKey = 'common.title_app',
  displayBackArrow = false,
  isNotKey,
  backFunction,
}: CozyBarProps) => {
  const { t } = useI18n()
  const history = useHistory()
  const dispatch = useDispatch()
  const { BarLeft, BarCenter, BarRight } = cozy.bar
  const { screenType } = useSelector((state: AppStore) => state.ecolyo.global)

  const handleClickBack = useCallback(() => {
    if (backFunction) {
      backFunction()
    } else {
      history.goBack()
    }
  }, [backFunction, history])

  const handleClickFeedbacks = () => {
    dispatch(updateModalIsFeedbacksOpen(true))
  }

  const cozyBarCustom = (screen?: ScreenType) => {
    if (screen === ScreenType.MOBILE) {
      return (
        <React.Fragment>
          {displayBackArrow && (
            <BarLeft>
              <StyledIconButton
                aria-label={t('header.accessibility.button_back')}
                className="cv-button"
                icon={BackArrowIcon}
                onClick={handleClickBack}
              />
            </BarLeft>
          )}
          <BarCenter>
            <div className="cozy-bar">
              <span className="app-title">
                {isNotKey ? titleKey : t(titleKey)}
              </span>
            </div>
          </BarCenter>
          <BarRight>
            <StyledIconButton
              aria-label={t('header.accessibility.button_open_feedbacks')}
              className="cv-button"
              icon={FeedbackIcon}
              sized={22}
              onClick={handleClickFeedbacks}
            />
          </BarRight>
        </React.Fragment>
      )
    }
    return null
  }

  return cozyBarCustom(screenType)
}

export default CozyBar
