import React from 'react'
import { mount } from 'enzyme'
import ConsumptionDetails from './ConsumptionDetails'
import * as reactRedux from 'react-redux'
import { TimeStep } from 'enum/timeStep.enum'
import { FluidType } from 'enum/fluid.enum'
import {
  createMockStore,
  mockInitialChartState,
  mockInitialEcolyoState,
  mockInitialGlobalState,
} from '../../../tests/__mocks__/store'
import { Provider } from 'react-redux'
import { BrowserRouter } from 'react-router-dom'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

const mockUseSelector = jest.spyOn(reactRedux, 'useSelector')

describe('ConsumptionDetails component', () => {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  let store: any

  beforeEach(() => {
    store = createMockStore(mockInitialEcolyoState)
    mockUseSelector.mockClear()
  })
  it('should be rendered correctly', () => {
    mockUseSelector.mockReturnValue({
      fluidStatus: mockInitialGlobalState.fluidStatus,
      fluidTypes: [FluidType.ELECTRICITY],
      selectedDate: mockInitialChartState.selectedDate,
      currentTimeStep: TimeStep.WEEK,
      currentIndex: mockInitialChartState.currentIndex,
      currentDatachart: mockInitialChartState.currentDatachart,
    })
    const wrapper = mount(
      <Provider store={store}>
        <BrowserRouter>
          <ConsumptionDetails fluidType={FluidType.ELECTRICITY} />
        </BrowserRouter>
      </Provider>
    )
    expect(wrapper).toMatchSnapshot()
  })

  it('should not render connection card ', () => {
    mockUseSelector.mockReturnValue({
      fluidStatus: mockInitialGlobalState.fluidStatus,
      fluidTypes: [FluidType.ELECTRICITY, FluidType.GAS, FluidType.WATER],
      selectedDate: mockInitialChartState.selectedDate,
      currentTimeStep: TimeStep.WEEK,
      currentIndex: mockInitialChartState.currentIndex,
      currentDatachart: mockInitialChartState.currentDatachart,
    })
    const wrapper = mount(
      <Provider store={store}>
        <BrowserRouter>
          <ConsumptionDetails fluidType={FluidType.MULTIFLUID} />
        </BrowserRouter>
      </Provider>
    )
    expect(wrapper.contains('.fluidcard-link')).toBeFalsy()
  })
  it('should render one connection card ', () => {
    mockUseSelector.mockReturnValue({
      fluidStatus: mockInitialGlobalState.fluidStatus,
      fluidTypes: [FluidType.ELECTRICITY, FluidType.GAS],
      selectedDate: mockInitialChartState.selectedDate,
      currentTimeStep: TimeStep.WEEK,
      currentIndex: mockInitialChartState.currentIndex,
      currentDatachart: mockInitialChartState.currentDatachart,
    })
    const wrapper = mount(
      <Provider store={store}>
        <BrowserRouter>
          <ConsumptionDetails fluidType={FluidType.MULTIFLUID} />
        </BrowserRouter>
      </Provider>
    )
    expect(wrapper.find('.fluidcard-link')).toBeTruthy()
  })
  it('should not render connection card and show multifluid link', () => {
    mockUseSelector.mockReturnValue({
      fluidStatus: mockInitialGlobalState.fluidStatus,
      fluidTypes: [FluidType.ELECTRICITY, FluidType.GAS],
      selectedDate: mockInitialChartState.selectedDate,
      currentTimeStep: TimeStep.WEEK,
      currentIndex: mockInitialChartState.currentIndex,
      currentDatachart: mockInitialChartState.currentDatachart,
    })
    const wrapper = mount(
      <Provider store={store}>
        <BrowserRouter>
          <ConsumptionDetails fluidType={FluidType.ELECTRICITY} />
        </BrowserRouter>
      </Provider>
    )
    expect(wrapper.find('.multi-link')).toBeTruthy()
  })
})
