import React from 'react'
import { mount } from 'enzyme'
import { Provider } from 'react-redux'
import {
  createMockStore,
  mockInitialEcolyoState,
  mockInitialGlobalState,
} from '../../../tests/__mocks__/store'

import { FluidState, FluidType } from 'enum/fluid.enum'
import FluidButton from './FluidButton'
import UsageEventService from 'services/usageEvent.service'
import configureStore from 'redux-mock-store'
import { GlobalState } from 'models'

jest.mock('cozy-ui/transpiled/react/I18n', () => {
  return {
    useI18n: jest.fn(() => {
      return {
        t: (str: string) => str,
      }
    }),
  }
})

describe('FluidButton component', () => {
  // eslint-disable-next-line @typescript-eslint/no-explicit-any
  let store: any
  beforeEach(() => {
    store = createMockStore(mockInitialEcolyoState)
  })

  it('should be rendered correctly', () => {
    const wrapper = mount(
      <Provider store={store}>
        <FluidButton fluidType={FluidType.ELECTRICITY} isActive={false} />
      </Provider>
    ).getElement()
    expect(wrapper).toMatchSnapshot()
  })

  it('should render multifluidButton', () => {
    const wrapper = mount(
      <Provider store={store}>
        <FluidButton fluidType={FluidType.MULTIFLUID} isActive={false} />
      </Provider>
    )
    expect(wrapper.find('.multifluid')).toBeTruthy()
  })
  it('should render active button', () => {
    const wrapper = mount(
      <Provider store={store}>
        <FluidButton fluidType={FluidType.GAS} isActive={false} />
      </Provider>
    )
    expect(wrapper.find('.active')).toBeTruthy()
  })

  it('should trigger nav event', () => {
    jest.mock('services/usageEvent.service')
    const mockAddEvent = jest.fn()
    UsageEventService.addEvent = mockAddEvent
    const wrapper = mount(
      <Provider store={store}>
        <FluidButton fluidType={FluidType.GAS} isActive={false} />
      </Provider>
    )
    wrapper.find('.fluid-button').simulate('click')
    expect(mockAddEvent).toHaveBeenCalled()
  })

  it('should render errored button', () => {
    const mockStore = configureStore([])

    const updatedInitalState: GlobalState = {
      ...mockInitialGlobalState,
    }
    updatedInitalState.fluidStatus[FluidType.GAS].status = FluidState.ERROR
    const store2 = mockStore({
      ecolyo: {
        global: updatedInitalState,
      },
    })
    const wrapper = mount(
      <Provider store={store2}>
        <FluidButton fluidType={FluidType.GAS} isActive={false} />
      </Provider>
    )
    expect(wrapper.find('.notif-error')).toBeTruthy()
  })
})
