import { useState, useEffect } from 'react'
import get from 'lodash/get'
import { useClient } from 'cozy-client'
import { UserInstanceSettings, UserInstanceSettingsAttributes } from 'models'

const useUserInstanceSettings = (): UserInstanceSettings => {
  const client = useClient()
  const [settings, setSettings] = useState<UserInstanceSettingsAttributes>({
    public_name: '',
  })
  const [fetchStatus, setFetchStatus] = useState<string>('idle')

  useEffect(() => {
    const fetchData = async () => {
      try {
        const response = await client
          .getStackClient()
          .fetchJSON('GET', '/settings/instance')
        setSettings(get(response, 'data.attributes'))
        setFetchStatus('loaded')
      } catch (error) {
        setFetchStatus('failed')
      }
    }
    fetchData()
  }, [client])

  return {
    data: settings,
    fetchStatus,
  }
}

export default useUserInstanceSettings
