import ActionView from 'components/Action/ActionView'
import ChallengeView from 'components/Challenge/ChallengeView'
import SgeConnectView from 'components/Connection/SGEConnect/SgeConnectView'
import DuelView from 'components/Duel/DuelView'
import EcogestureFormView from 'components/EcogestureForm/EcogestureFormView'
import EcogestureSelection from 'components/EcogestureSelection/EcogestureSelection'
import ExplorationView from 'components/Exploration/ExplorationView'
import UnSubscribe from 'components/Options/Unsubscribe/UnSubscribe'
import QuizView from 'components/Quiz/QuizView'
import TermsView from 'components/Terms/TermsView'
import { FluidType } from 'enum/fluid.enum'
import { TermsStatus } from 'models'
import React, { lazy, Suspense } from 'react'
import { Redirect, Route, Switch } from 'react-router-dom'

const ConsumptionView = lazy(() => import('components/Home/ConsumptionView'))

const EcogestureView = lazy(
  () => import('components/Ecogesture/EcogestureView')
)
const SingleEcogesture = lazy(
  () => import('components/Ecogesture/SingleEcogesture')
)
const OptionsView = lazy(() => import('components/Options/OptionsView'))
const LegalNoticeView = lazy(
  () => import('components/LegalNotice/LegalNoticeView')
)
const GCUView = lazy(() => import('components/GCU/GCUView'))
const AnalysisView = lazy(() => import('components/Analysis/AnalysisView'))
const ProfileTypeView = lazy(
  () => import('components/ProfileType/ProfileTypeView')
)

interface RouteProps {
  termsStatus: TermsStatus
}
const Routes: React.FC<RouteProps> = ({ termsStatus }: RouteProps) => {
  return (
    <Suspense fallback={<div></div>}>
      <Switch>
        {termsStatus.accepted && <Redirect from="/terms" to="/consumption" />}
        <Route path="/terms" component={TermsView} />
        {!termsStatus.accepted && (
          <>
            <Redirect from="*" to="/terms" />
            <Redirect from="/" to="/terms" />
          </>
        )}
        <Route path={`/consumption/electricity`} exact>
          <ConsumptionView fluidType={FluidType.ELECTRICITY} />
        </Route>
        <Route path={`/consumption/water`} exact>
          <ConsumptionView fluidType={FluidType.WATER} />
        </Route>
        <Route path={`/consumption/gas`} exact>
          <ConsumptionView fluidType={FluidType.GAS} />
        </Route>
        <Route path={`/consumption`} exact>
          <ConsumptionView fluidType={FluidType.MULTIFLUID} />
        </Route>

        <Route path={`/sge-connect`} component={SgeConnectView} />
        <Route path={`/challenges/duel`} component={DuelView} />
        <Route path={`/challenges/quiz`} component={QuizView} />
        <Route path={`/challenges/exploration`} component={ExplorationView} />
        <Route path={`/challenges/action`} exact component={ActionView} />
        <Route path={`/challenges/`} component={ChallengeView} exact />
        <Route path="/ecogesture-form" component={EcogestureFormView} />
        <Route path="/ecogesture-selection" component={EcogestureSelection} />
        <Route path="/ecogesture/:id/:tab" component={SingleEcogesture} />
        <Route path="/ecogesture/:id" component={SingleEcogesture} />
        <Route path={`/ecogestures`} component={EcogestureView} />
        <Route path={`/ecogestures`} component={EcogestureView} />
        <Route path={`/options/legalnotice`} component={LegalNoticeView} />
        <Route path={`/options/gcu`} component={GCUView} />
        <Route path={'/options/:connectParam'} exact component={OptionsView} />
        <Route path={'/options'} exact component={OptionsView} />
        <Route path="/analysis" component={AnalysisView} />
        <Route path="/profiletype" component={ProfileTypeView} />
        <Route path="/unsubscribe" component={UnSubscribe} />

        <Redirect from="/" to="/consumption" />
        <Redirect from="*" to="/consumption" />
      </Switch>
    </Suspense>
  )
}

export default Routes
