import { Dataload, UserChallenge } from 'models'

export const SET_USER_CHALLENGE_LIST = 'SET_USER_CHALLENGE_LIST'
export const UPDATE_USER_CHALLENGE_LIST = 'UPDATE_USER_CHALLENGE_LIST'
export const UNLOCK_NEXT_USER_CHALLENGE = 'UNLOCK_NEXT_USER_CHALLENGE'
export const SET_CHALLENGE_CONSUMPTION = 'SET_CHALLENGE_CONSUMPTION'

interface SetUserChallengeList {
  type: typeof SET_USER_CHALLENGE_LIST
  payload?: UserChallenge[]
}

interface UpdateUserChallengeList {
  type: typeof UPDATE_USER_CHALLENGE_LIST
  payload?: UserChallenge
}

interface UnlockNextUserChallenge {
  type: typeof UNLOCK_NEXT_USER_CHALLENGE
  payload?: UserChallenge
}

interface SetChallengeConsumption {
  type: typeof SET_CHALLENGE_CONSUMPTION
  payload?: { userChallenge: UserChallenge; currentDataload: Dataload[] }
}

export type ChallengeActionTypes =
  | SetUserChallengeList
  | UpdateUserChallengeList
  | UnlockNextUserChallenge
  | SetChallengeConsumption

export function setUserChallengeList(
  userChallengeList: UserChallenge[]
): ChallengeActionTypes {
  return {
    type: SET_USER_CHALLENGE_LIST,
    payload: userChallengeList,
  }
}

export function updateUserChallengeList(
  userChallenge: UserChallenge
): ChallengeActionTypes {
  return {
    type: UPDATE_USER_CHALLENGE_LIST,
    payload: userChallenge,
  }
}

export function unlockNextUserChallenge(
  userChallenge: UserChallenge
): ChallengeActionTypes {
  return {
    type: UNLOCK_NEXT_USER_CHALLENGE,
    payload: userChallenge,
  }
}

export function setChallengeConsumption(
  userChallenge: UserChallenge,
  currentDataload: Dataload[]
): ChallengeActionTypes {
  return {
    type: SET_CHALLENGE_CONSUMPTION,
    payload: { userChallenge, currentDataload },
  }
}
