import { FluidState, FluidType } from 'enum/fluid.enum'
import { FluidSlugType } from 'enum/fluidSlug.enum'
import { ScreenType } from 'enum/screen.enum'
import { DateTime } from 'luxon'
import { FluidStatus } from 'models'
import { accountsData } from '../../../tests/__mocks__/accountsData.mock'
import { mockCustomPopup } from '../../../tests/__mocks__/customPopup.mock'
import { konnectorsData } from '../../../tests/__mocks__/konnectorsData.mock'
import { mockInitialGlobalState } from '../../../tests/__mocks__/store'
import { triggersData } from '../../../tests/__mocks__/triggersData.mock'
import {
  CHANGE_SCREEN_TYPE,
  SET_CUSTOM_POPUP,
  SET_FLUID_STATUS,
  TOGGLE_ANALYSIS_NOTIFICATION,
  TOGGLE_CHALLENGE_ACTION_NOTIFICATION,
  TOGGLE_CHALLENGE_DUEL_NOTIFICATION,
  TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION,
} from './global.actions'
import { globalReducer } from './global.reducer'

const mockDataDates: (DateTime | null)[] = [
  DateTime.local().setZone('utc', {
    keepLocalTime: true,
  }),
  DateTime.local().setZone('utc', {
    keepLocalTime: true,
  }),
  DateTime.local().setZone('utc', {
    keepLocalTime: true,
  }),
]

describe('global reducer', () => {
  it('should return the initial state', () => {
    const result = globalReducer(undefined as any, { type: 'default' })
    expect(result).toEqual(mockInitialGlobalState)
  })

  it('should handle CHANGE_SCREEN_TYPE with payload', () => {
    const result = globalReducer(mockInitialGlobalState, {
      type: CHANGE_SCREEN_TYPE,
      payload: ScreenType.DESKTOP,
    })
    expect(result).toEqual({
      ...mockInitialGlobalState,
      screenType: ScreenType.DESKTOP,
    })
  })

  it('should handle CHANGE_SCREEN_TYPE without payload', () => {
    const result = globalReducer(mockInitialGlobalState, {
      type: CHANGE_SCREEN_TYPE,
    })
    expect(result).toEqual(mockInitialGlobalState)
  })

  it('should handle TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION with payload', () => {
    const result = globalReducer(mockInitialGlobalState, {
      type: TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION,
      payload: true,
    })
    expect(result).toEqual({
      ...mockInitialGlobalState,
      challengeExplorationNotification: true,
    })
  })

  it('should handle TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION without payload', () => {
    const result = globalReducer(mockInitialGlobalState, {
      type: TOGGLE_CHALLENGE_EXPLORATION_NOTIFICATION,
    })
    expect(result).toEqual(mockInitialGlobalState)
  })

  it('should handle TOGGLE_CHALLENGE_ACTION_NOTIFICATION with payload', () => {
    const result = globalReducer(mockInitialGlobalState, {
      type: TOGGLE_CHALLENGE_ACTION_NOTIFICATION,
      payload: true,
    })
    expect(result).toEqual({
      ...mockInitialGlobalState,
      challengeActionNotification: true,
    })
  })

  it('should handle TOGGLE_CHALLENGE_ACTION_NOTIFICATION without payload', () => {
    const result = globalReducer(mockInitialGlobalState, {
      type: TOGGLE_CHALLENGE_ACTION_NOTIFICATION,
    })
    expect(result).toEqual(mockInitialGlobalState)
  })

  it('should handle TOGGLE_CHALLENGE_DUEL_NOTIFICATION with payload', () => {
    const result = globalReducer(mockInitialGlobalState, {
      type: TOGGLE_CHALLENGE_DUEL_NOTIFICATION,
      payload: true,
    })
    expect(result).toEqual({
      ...mockInitialGlobalState,
      challengeDuelNotification: true,
    })
  })

  it('should handle TOGGLE_CHALLENGE_DUEL_NOTIFICATION without payload', () => {
    const result = globalReducer(mockInitialGlobalState, {
      type: TOGGLE_CHALLENGE_DUEL_NOTIFICATION,
    })
    expect(result).toEqual(mockInitialGlobalState)
  })

  it('should handle TOGGLE_ANALYSIS_NOTIFICATION with payload', () => {
    const result = globalReducer(mockInitialGlobalState, {
      type: TOGGLE_ANALYSIS_NOTIFICATION,
      payload: true,
    })
    expect(result).toEqual({
      ...mockInitialGlobalState,
      analysisNotification: true,
    })
  })

  it('should handle TOGGLE_ANALYSIS_NOTIFICATION without payload', () => {
    const result = globalReducer(mockInitialGlobalState, {
      type: TOGGLE_ANALYSIS_NOTIFICATION,
    })
    expect(result).toEqual(mockInitialGlobalState)
  })

  it('should handle SET_FLUID_STATUS with payload', () => {
    const fluidStatus: FluidStatus[] = [
      {
        fluidType: FluidType.ELECTRICITY,
        status: FluidState.ERROR,
        maintenance: false,
        firstDataDate: mockDataDates[FluidType.ELECTRICITY],
        lastDataDate: mockDataDates[FluidType.ELECTRICITY],
        connection: {
          konnector: konnectorsData[0],
          account: accountsData[0],
          trigger: triggersData[0],
          triggerState: null,
          shouldLaunchKonnector: false,
          isUpdating: false,
          konnectorConfig: {
            name: 'Enedis',
            oauth: true,
            slug: FluidSlugType.ELECTRICITY,
            siteLink: 'https://mon-compte-particulier.enedis.fr/donnees/',
            activation: 'https://mon-compte-particulier.enedis.fr/donnees/',
          },
        },
      },
      {
        fluidType: FluidType.WATER,
        status: FluidState.ERROR,
        maintenance: false,
        firstDataDate: mockDataDates[FluidType.WATER],
        lastDataDate: mockDataDates[FluidType.WATER],
        connection: {
          konnector: konnectorsData[1],
          account: accountsData[1],
          trigger: triggersData[1],
          triggerState: null,
          shouldLaunchKonnector: false,
          isUpdating: false,
          konnectorConfig: {
            name: 'Eau Publique du Grand Lyon',
            oauth: false,
            slug: FluidSlugType.WATER,
            siteLink:
              'https://agence.eaudugrandlyon.com/inscription.aspx#subc-now',
            activation: '',
          },
        },
      },
      {
        fluidType: FluidType.GAS,
        status: FluidState.KONNECTOR_NOT_FOUND,
        maintenance: false,
        firstDataDate: mockDataDates[FluidType.GAS],
        lastDataDate: mockDataDates[FluidType.GAS],
        connection: {
          konnector: null,
          account: accountsData[2],
          trigger: null,
          triggerState: null,
          shouldLaunchKonnector: false,
          isUpdating: false,
          konnectorConfig: {
            name: 'GRDF',
            oauth: true,
            slug: FluidSlugType.GAS,
            siteLink: 'https://monespace.grdf.fr/monespace/connexion',
            activation: '',
          },
        },
      },
    ]
    const result = globalReducer(mockInitialGlobalState, {
      type: SET_FLUID_STATUS,
      payload: fluidStatus,
    })
    expect(result).toEqual({
      ...mockInitialGlobalState,
      fluidStatus: fluidStatus,
      fluidTypes: [FluidType.ELECTRICITY, FluidType.WATER],
    })
  })

  it('should handle SET_FLUID_STATUS without payload', () => {
    const result = globalReducer(mockInitialGlobalState, {
      type: SET_FLUID_STATUS,
    })
    expect(result).toEqual(mockInitialGlobalState)
  })

  it('should handle SET_CUSTOM_POPUP with payload', () => {
    const result = {
      ...mockInitialGlobalState,
      customPopupModal: mockCustomPopup,
    }
    expect(
      globalReducer(mockInitialGlobalState, {
        type: SET_CUSTOM_POPUP,
        payload: mockCustomPopup,
      }).customPopupModal
    ).toBe(result.customPopupModal)
  })
})
